@@ -192,8 +192,8 @@ class PhContextFacade(object):
             line = line + "\n"
             if line == "$alfred_import_jobs\n":
                 for j in config.spec.jobs:
-                    # w.write("from phjobs." + j.name + ".phjob import execute as " + j.name + "\n")
-                    w.write("from phjobs." + j.name + " import execute as " + j.name + "\n")
+                    w.write("from phjobs." + j.name + ".phjob import execute as " + j.name + "\n")
+                    # w.write("from phjobs." + j.name + " import execute as " + j.name + "\n")
             else:
                 w.write(
                     line.replace("$alfred_dag_owner", str(config.spec.owner)) \
